import React, { useRef, useState, useCallback, useEffect } from 'react';

var classes = {"IndicatorContainer":"_Indicator-module__IndicatorContainer__3I7vF","IndicatorContent":"_Indicator-module__IndicatorContent__3kdsN","Indicators":"_Indicator-module__Indicators__2vhHh","Active":"_Indicator-module__Active__2qRu_"};

function Indicator({
  itemsPerSlide,
  itemGap,
  children
}) {
  const indicatorsRef = useRef(null);
  const itemsRef = useRef(null);
  const [numberOfIndicators, setNumberOfItems] = useState(() => {
    const childrenCount = React.Children.count(children);
    return Math.ceil(childrenCount / itemsPerSlide);
  });
  const calculateIndicatorDimensions = useCallback(() => {
    const childrenCount = React.Children.count(children);
    const numberOfIndicators = Math.ceil(childrenCount / itemsPerSlide);

    for (const item of itemsRef.current.children) {
      item.style.minWidth = Math.ceil(itemsRef.current.offsetWidth / itemsPerSlide) - itemGap + 'px';
      item.style.marginRight = itemGap + 'px';
    }

    setNumberOfItems(numberOfIndicators);
  }, [children, itemGap, itemsPerSlide]);
  useEffect(() => {
    window.addEventListener('resize', calculateIndicatorDimensions);
    return () => {
      window.removeEventListener('resize', calculateIndicatorDimensions);
    };
  }, [calculateIndicatorDimensions]);
  useEffect(() => {
    calculateIndicatorDimensions();
  }, [calculateIndicatorDimensions]);

  const indicatorChangeHandler = e => {
    const indicatorId = +e.target.dataset.indicator;

    for (const indicator of indicatorsRef.current.children) {
      if (indicator.classList.contains(classes.Active)) {
        indicator.classList.remove(classes.Active);
      }
    }

    e.target.classList.add(classes.Active);
    itemsRef.current.style.transform = `translateX(-${indicatorId * itemsRef.current.offsetWidth}px)`;
  };

  return /*#__PURE__*/React.createElement("div", {
    className: classes.IndicatorContainer
  }, /*#__PURE__*/React.createElement("div", {
    className: classes.IndicatorContent,
    ref: itemsRef
  }, children), /*#__PURE__*/React.createElement("div", {
    className: classes.Indicators,
    ref: indicatorsRef
  }, [...new Array(numberOfIndicators)].map((btn, index) => /*#__PURE__*/React.createElement("button", {
    key: index,
    className: `${index === 0 ? classes.Active : ''}`,
    "data-indicator": index,
    onClick: indicatorChangeHandler
  }))));
}

export default Indicator;
//# sourceMappingURL=index.modern.js.map
